@@ -1,6 +1,6 @@
 #! /bin/sh
 # check script for Lzd - Educational decompressor for the lzip format
-# Copyright (C) 2013-2022 Antonio Diaz Diaz.
+# Copyright (C) 2013-2024 Antonio Diaz Diaz.
 #
 # This script is free software: you have unlimited permission
 # to copy, distribute, and modify it.
@@ -41,20 +41,20 @@ printf "testing lzd-%s..." "$2"
 [ $? = 2 ] || test_failed $LINENO
 
 for i in "${in_lz}" "${in_em}" ; do
-	"${LZIP}" < "$i" > copy || test_failed $LINENO "$i"
-	cmp "${in}" copy || test_failed $LINENO "$i"
+	"${LZIP}" < "$i" > out || test_failed $LINENO "$i"
+	cmp "${in}" out || test_failed $LINENO "$i"
 done
 
 cat "${in}" "${in}" > in2 || framework_failure
-cat "${in_lz}" "${in_lz}" | "${LZIP}" > copy2 || test_failed $LINENO
-cmp in2 copy2 || test_failed $LINENO
-rm -f copy2 || framework_failure
+cat "${in_lz}" "${in_lz}" | "${LZIP}" > out2 || test_failed $LINENO
+cmp in2 out2 || test_failed $LINENO
+rm -f out2 || framework_failure
 
-cat "${in_lz}" "${in_lz}" > copy2.lz || framework_failure
-printf "\ngarbage" >> copy2.lz || framework_failure
-"${LZIP}" -d < copy2.lz > copy2 || test_failed $LINENO
-cmp in2 copy2 || test_failed $LINENO
-rm -f in2 copy2 copy2.lz || framework_failure
+cat "${in_lz}" "${in_lz}" > out2.lz || framework_failure
+printf "\ngarbage" >> out2.lz || framework_failure
+"${LZIP}" -d < out2.lz > out2 || test_failed $LINENO
+cmp in2 out2 || test_failed $LINENO
+rm -f in2 out2 out2.lz || framework_failure
 
 printf "\ntesting bad input..."
 
@@ -90,9 +90,9 @@ rm -f in2.lz in3.lz trunc.lz || framework_failure
 cat "${in_lz}" > ingin.lz || framework_failure
 printf "g" >> ingin.lz || framework_failure
 cat "${in_lz}" >> ingin.lz || framework_failure
-"${LZIP}" -d < ingin.lz > copy || test_failed $LINENO
-cmp "${in}" copy || test_failed $LINENO
-rm -f copy ingin.lz || framework_failure
+"${LZIP}" -d < ingin.lz > out || test_failed $LINENO
+cmp "${in}" out || test_failed $LINENO
+rm -f out ingin.lz || framework_failure
 
 echo
 if [ ${fail} = 0 ] ; then
